@@ -3,12 +3,12 @@ function(checked,resmass,nknots=13,spar=0.1,plotit=TRUE){
 
     ############################################################################
     # (1) issue warnings #######################################################
-	if(length(resmass[,1])<10){stop("WARNING: not enough data points in resmass\n");}
-    if(any(checked[,3]<min(resmass[,1])) || any(checked[,3]>max(resmass[,1]))){stop("WARNING: some mean_mass out of range of resmass\n");}
-    if(nknots<3 || nknots>length(resmass[,1])){stop("WARNING: invalid nknots\n")}
-    if(spar<=0 || spar>=1){stop("WARNING: invalid spar; spar=(0,1]")}
-    if(plotit!="TRUE"&plotit!="FALSE"){stop("WARNING: plotit invalid. TRUE, FALSE.\n")}
-    if(any(checked[,1]==TRUE)){stop("WARNING: warning in checked[,1] ... invalid chemical formula!")}
+	if(length(resmass[,1])<10){stop("stop: not enough data points in resmass\n");}
+    if(any(checked[,3]<min(resmass[,1])) || any(checked[,3]>max(resmass[,1]))){stop("stop: some mean_mass out of range of resmass\n");}
+    if(nknots<3 || nknots>length(resmass[,1])){stop("stop: invalid nknots\n")}
+    if(spar<=0 || spar>=1){stop("stop: invalid spar; spar=(0,1]")}
+    if(plotit!="TRUE"&plotit!="FALSE"){stop("stop: plotit invalid. TRUE, FALSE.\n")}
+    if(any(checked[,1]==TRUE)){stop("stop: in checked[,1] ... invalid chemical formula!")}
     options(digits=10);
     ############################################################################
     # (2) fit gam model ########################################################
